@@ -1,5 +1,6 @@
 #' Retrieve user (self) blocks
 #'
+#' @param cursor `r template_var_cursor()`
 #' @param limit `r template_var_limit(100)`
 #' @param user `r template_var_user()`
 #' @param pass `r template_var_pass()`
@@ -19,7 +20,7 @@
 #'
 #' @examplesIf has_bluesky_pass() && has_bluesky_user()
 #' bs_get_blocks()
-bs_get_blocks <- function(limit = NULL,
+bs_get_blocks <- function(cursor = NULL, limit = NULL,
                           user = get_bluesky_user(), pass = get_bluesky_pass(),
                           auth = bs_auth(user, pass), clean = TRUE) {
 
@@ -29,7 +30,9 @@ bs_get_blocks <- function(limit = NULL,
     }
     limit <- as.integer(limit)
     limit <- max(limit, 1L)
-    limit <- min(limit, 100L)
+    req_seq <- diff(unique(c(seq(0, limit, 100), limit)))
+  } else {
+    req_seq <- list(NULL)
   }
 
   req <- httr2::request('https://bsky.social/xrpc/app.bsky.graph.getBlocks') |>
@@ -37,12 +40,18 @@ bs_get_blocks <- function(limit = NULL,
     httr2::req_url_query(
       limit = limit
     )
-  resp <- req |>
-    httr2::req_perform() |>
-    httr2::resp_body_json()
+  resp <- repeat_request(req, req_seq, cursor, txt = 'Fetching blocks')
 
   if (!clean) return(resp)
 
+  resp |>
+    lapply(process_blocks) |>
+    purrr::list_rbind() |>
+    add_req_url(req) |>
+    add_cursor(resp)
+}
+
+process_blocks <- function(resp) {
   resp |>
     purrr::pluck('blocks') |>
     proc() |>
